#!/bin/ksh
########################################################
# @(#) install.sh 07/05/28 13:23:33
# @(#) 
# Copyright 2008 IBM Corp.
########################################################

########################################################
# 
# MotoCDMA Direct RP4 -> MotoCDMA Direct RP4.1 Server Upgrade script
# 
########################################################

  RELEASE="MotoCDMA"
  VERSION="20.0.4.1.0"
  BUILD="2"

  FULL_VER="${VERSION}.${BUILD}"

########################################################

  SOURCE_DIR="$FLEXPM_BASE/patches/$FULL_VER/$RELEASE/$FULL_VER"
  BACKUP_DIR="$FLEXPM_BASE/patches/$FULL_VER/$RELEASE/$FULL_VER/backup.${FULL_VER}"

########################################################

  function patchsql 
  {
    echo Patching: $1
    echo "WHENEVER SQLERROR CONTINUE;\nSET SERVEROUTPUT ON SIZE 1000000;\nSET TIMING ON;\n@ $1 \nEXIT;" | sqlplus -S $DB_CONNECT
    status=$?
    test "${status}" = "0" || exit ${status}
  }

########################################################

 echo "$RELEASE RP4 -> RP4.1 Server Upgrade"
 echo "Start: " `date`
    
########################################################
echo "Checking environment..."
########################################################

  if ! [[ -d ${FLEXPM_HOME} ]]; then
    echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    exit;
  fi

  if ! [[ -d ${FLEXPM_BASE} ]]; then
    echo "Env variable FLEXPM_BASE must be set to appropriate dir before installation."
    exit;
  fi

  if ! [[ -d ${PM_HOME} ]]; then
    echo "Env variable FLEXPM_BASE must be set to appropriate dir before installation."
    exit;
  fi
  
  if ! [[ -d ${MotoCDMA_HOME} ]]; then
    echo "Env variable MotoCDMA_HOME must be set to appropriate dir before installation."
    exit;
  fi

  if [[ -z ${DB_CONNECT} ]]; then
     echo "Env variable DB_CONNECT must be set to approriate database connection values."
     exit;
  fi
  
  if [[ -d ${BACKUP_DIR} ]]; then
           echo "Patch ${RELEASE} may have been already applied. Please verify.\n"
           exit;
  else
           mkdir -p -m 744 ${BACKUP_DIR}
  fi

       ####################### pre-requisite validation ###########################
       ############################################################################

       pre_err="N"

       ### chk for PERL5LIB
       echo $PERL5LIB | grep "$PM_HOME/sw/perl/lib"
       ret=$?

       if [ $ret == 1 ] ; then
	  export PERL5LIB=$PM_HOME/sw/perl/lib
       fi

       ### chk for perl version
       perl -v | fgrep 5.6.1 >/dev/null 2>&1
       ret=$?

       if [ "$force" == "N" ] &&  [ $ret == 1 ] ; then
          echo
          echo "Invalid perl version.  Prospect must be using perl version 5.6.1!"
          pre_err="Y" 
       fi

       ### chk for java version
       ret=`java -version 2>&1 | sed -n -e '/java version/{ s/^.* "//; s/".*$//; s/_.*//; p;}' | awk -F. '{ printf("%02d.%02d.%02d\n",$1,$2,$3)}' `

       if [ "$force" == "N" ] && [[ $ret < 01.05.00 ]] ; then
          echo
          echo "Invalid Java version.  Java version must be same as or above 01.05.00!"
          pre_err="Y"
       fi 

       ### chk for conflict variable

       if [ "$force" == "N" ] && ! [ -z ${LOG} ] ; then
          echo
          echo "Variable \$LOG is defined.  This might impact on Prospect System.  Please unset this varable manually by typing 'unset LOG'"
          pre_err="Y"
       fi

        if [ "$force" == "N" ] && ! [ -z ${OK} ] ; then
          echo
          echo "Variable \$OK is defined.  This might impact on Prospect System.  Please unset this varable manually by typing 'unset OK'"
          pre_err="Y"
       fi

       if [ "$pre_err" == "Y" ] ; then
          echo
          echo "Error in pre-requisite validation.  Please contact IBM Customer Support before proceeding installation."
          exit 3;
       fi

      #################### End of pre-requisite validation #######################
      ############################################################################
  
########################################################
echo "Installing updated source files..."
########################################################

  cd $SOURCE_DIR/sources
  for new_dir in `find . -type d|cut -c3-`
  do
        if [[ -d ${FLEXPM_BASE}/$new_dir ]]; then
          echo "dir ok: $new_dir"
        else
          echo "create: $new_dir"
          mkdir -p ${FLEXPM_BASE}/$new_dir
        fi

  done

  touch ${BACKUP_DIR}/backup_sources.tar

  cd $SOURCE_DIR/sources

  for new_file in `find . -type f|cut -c3-`
  do
        cd ${FLEXPM_BASE}
        if [[ -f $new_file ]];
        then
          echo "backup: ${FLEXPM_BASE}/$new_file"
          /usr/sfw/bin/gtar -uf ${BACKUP_DIR}/backup_sources.tar $new_file
          chmod +w $new_file
        fi
        echo "update: ${FLEXPM_BASE}/$new_file"
        cp -p ${SOURCE_DIR}/sources/$new_file $new_file
  
  done

########################################################
echo "Setup bits..."
########################################################

cd $FLEXPM_HOME
chmod +x pm/adm/setup-exec-bits
setup-exec-bits -set

########################################################
######### AE UPGRADE STARTS HERE  
########################################################

  cd $SOURCE_DIR
  ./Fix_SEAde65678.sh

  # vendor upgrade starts here
  cd $MotoCDMA_HOME/peik
  make dict_update

  #Make R21 sentry 
  echo "+ Creating directory for MotoCDMA R21..."
  ${MotoCDMA_HOME}/vendor/Motorola/MSC/1.3/scripts/mkdirs.sh ${MotoCDMA_HOME}/vendor/Motorola/MSC/1.3/MotoCDMA_data

########################################################
    echo "+ Updating loader ..."
########################################################

  #Make OMCR_PM loader
  echo "+ Update OMCR_PM datatype..."
  cd $MotoCDMA_HOME/vendor/Motorola/MSC/1.3/MotoCDMA_loader/OMCR_PM/config
  make clean
  make all

  #Make OMCR_VPU loader
  echo "+ Update OMCR_VPU datatype..."
  cd $MotoCDMA_HOME/vendor/Motorola/MSC/1.3/MotoCDMA_loader/OMCR_VPU/config
  make clean
  make all

  #Make PMServer_PM loader
  echo "+ Update PMServer_PM datatype..."
  cd $MotoCDMA_HOME/vendor/Motorola/MSC/1.3/MotoCDMA_loader/PMServer_PM/config
  make clean
  make all

  ##Miscelleneous update
  cd $MotoCDMA_HOME/vendor/Motorola/MSC/1.3/MotoCDMA_data
  make clean
  make all

########################################################
echo "+ Make jloader..."
########################################################

  cd $MotoCDMA_HOME/vendor/Motorola/MSC/jloader
  make all

# The code may change from releases
  cd $SOURCE_DIR
  echo "@recreate_temp_tab_RP4.1.sql" | sqlplus $DB_CONNECT

  cd $MotoCDMA_HOME/vendor/Motorola/MSC/1.3/MotoCDMA_loader/OMCR_PM/jloader
  rm -f *.o
  echo "@mot_jloader_omcr_pmPack.sql" | sqlplus $DB_CONNECT
  echo "@mot_jloader_omcr_pm.sql" | sqlplus $DB_CONNECT

  cd $MotoCDMA_HOME/vendor/Motorola/MSC/1.3/MotoCDMA_loader/PMServer_PM/jloader
  rm -f *.o
  echo "@mot_jloader_pmserver_pmPack.sql" | sqlplus $DB_CONNECT
  echo "@mot_jloader_pmserver_pm.sql" | sqlplus $DB_CONNECT

patchsql $SOURCE_DIR/upgrade_summations.sql
patchsql $SOURCE_DIR/restore_part_maint.sql
patchsql $SOURCE_DIR/regen_XML.sql
patchsql $SOURCE_DIR/wmload_create.sql
patchsql $SOURCE_DIR/hide_oem_kci.sql

$SOURCE_DIR/recompile_schema.sh
$SOURCE_DIR/recompile_view.sh

patchsql $NE_BASE/insertmap.sql
patchsql $NE_BASE/entityorder.sql

########################################################
######### AE UPGRADE ENDS HERE  
########################################################
 
cd $SOURCE_DIR
  
  echo "End: " `date`
  
  echo "Installation Complete - Check for errors."
  
########################################################
