#!/bin/sh
# @(#) COPYRIGHT WatchMark Corp 2004
# @(#) mkdirs.sh = generate directories for sentry/commander/loader
# USAGE:  mkdirs.sh [ -v ][ directory ][ -Rxx ]
#   -v|-verbose = show results of each step
#   directory   = pathname alternative to ${PROSPECT_HOME}
#   -Rxx | -rxx = release subdirectory (eg., -R15 | -R16 | ... )
# EXAMPLE:
#   $ sh db/Oracle8i/creation_scripts/mkdirs.sh		;# all by default
#   $ sh db/Oracle8i/creation_scripts/mkdirs.sh	-R15	;# build just one
# NOTES:
#   uses 'PROSPECT_HOME' for default directory
#   builds directories for each "Rxx" (default = R13,R14,R15,R16)
# FILES:
#   ${PROSPECT_HOME}/../ftpIN/sentryLogs
#   ${PROSPECT_HOME}/../ftpIN/Rxx/in
#   ${PROSPECT_HOME}/../ftpIN/Rxx/ok
#   ${PROSPECT_HOME}/../ftpIN/Rxx/fail
#   ${PROSPECT_HOME}/../ftpIN/Rxx/logs
# SEE ALSO:
#   ${PROSPECT_HOME}/../ftpIN/omp-transfer
# @(#) mkdirs.sh 1.19.0 04/09/27 19:12:11

#
##  give help if asked
#
    ToolName="`basename $0`"
    case $1 in
    -help|-usage)
	echo "?($ToolName) usage information -- " 1>&2
	grep "^# " $0 1>&2
	exit 2
	;;
    esac
#
##  set handler for Interrupt/Quit Signals
#
    trap 'echo ; echo "** Interrupt **" ; exit ' 1 2 3 15
##
    lx() {
	/bin/ls -l $@ | /bin/cut -c1-11,33-333 1>&2
    }
#
##  scan command args
#
    Option="--"
    Subset="
	R18
	R19
	R20
	R21
	R22
    "

    while true
    do
	case $1 in
	'') break ;;

	-V  | -v  ) Option="-v" ; shift ;;
#	-R* | -r* ) Subset=` echo "$1" | tr -dc '[0-9]' ` ; shift ;;
	-R* | -r* ) Subset=` echo "$1" | tr -d '-' ` ; shift ;;

	-d) shift ; PROSPECT_HOME="$1" ; shift ;;
	-*) echo "?($ToolName) unknown option: \"$1\"" 1>&2 ; exit 1 ;;
	* )         PROSPECT_HOME="$1" ; shift ;;
	esac
    done
#
##  confirm environment setting, check directory
#
    if   test ! -n "${MotoCDMA_HOME}"
    then echo "?($ToolName) variable not set: \"\$MotoCDMA_HOME\"" 1>&2 ; exit 1
    fi
    
    if   test ! -d "${MotoCDMA_HOME}"
    then echo "?($ToolName) missing directory: \"$MotoCDMA_HOME\"" 1>&2 ; exit 1
    fi
#
##  construct basic framework
#
    echo

    mkdir -p ${MotoCDMA_HOME}/vendor/Motorola/MSC/ftpIN/MotoCDMA
    lx -ld   ${MotoCDMA_HOME}/vendor/Motorola/MSC/ftpIN/MotoCDMA
    cd       ${MotoCDMA_HOME}/vendor/Motorola/MSC/ftpIN/MotoCDMA

#  rcp is not needed for motorola
#    mkdir -p ${PROSPECT_HOME}/../ftpIN/rcp	;# see 'omp-transfer'
#
##  generate directories for sentry/commander/loader
#
    {
    echo "../sentryLogs"

    for Rxx in ${Subset}
    do  :
	for Name in \
	    ../MotoCDMA/${Rxx}/in     \
	    ../MotoCDMA/${Rxx}/ok     \
	    ../MotoCDMA/${Rxx}/fail   \
	    ../MotoCDMA/${Rxx}/archives \
	    ../MotoCDMA/${Rxx}/logs   \
	    ;
	do  :
	    echo "${Name}"
	done
    done
    } | \
    \
    while read Directory
    do
	test "${Option}" != "-v" && \
	    echo 1>&2 " Creating directory  \"${Directory}\""

	mkdir -p "${Directory}"

	test "${Option}" != "-v" || \
	    lx -ld   "${Directory}"
    done

    echo
#.
