--
--
-- COPYRIGHT Vallent Corp 2005-2006
--
-- Create MOT_JLOADER_COMMON package body, consisting of procedures/functions used by multiple loaders
--
-- author: yeohe
--
-- date: 30Oct06

CREATE OR REPLACE PACKAGE BODY MOT_JLOADER_COMMON AS

g_bsc_tab VARCHAR2(30) := 'MOT_PM_MAP_BSC_TAB';
g_bts_band_tab VARCHAR2(30) := 'MOT_PM_MAP_BTS_BAND_TAB';
g_bts_band_tmp VARCHAR2(30) := 'MOT_PM_MAP_BTS_BAND_TMP';

-- update_bts_band_tmp introduced for valnt00013005

PROCEDURE update_bts_band_tmp (P_SYSTEM_ID IN INTEGER, P_MSC_ID IN INTEGER, P_BSC_ID IN INTEGER, P_CARR_MAP_TAB IN VARCHAR2)
AS
  v_sql VARCHAR2(5000);
  
BEGIN
  -- TODO: Does P_CARR_MAP_TAB really needs to be passed in? This is specific to MOT_PM_85_CARR_MAP_TAB only

  -- First, insert/update all low sector bandclass
  -- Do NOT ignore the UPDATE, because CDMA AEMS loader uses this same procedure.
  -- Otherwise, you may get a unique constraint error in $PM_LOGS/loader.log
  
  v_sql := 'MERGE INTO ' || g_bts_band_tmp || ' D USING ('
  		   || ' SELECT bb.system_id, bsc.msc_id, bb.bsc_id, bb.bts_id, c85.carrier_index, bb.bandclass1 AS low_sector_bandclass '
		   || ' FROM ' || g_bts_band_tab || ' bb, ' || P_CARR_MAP_TAB || ' c85, ' || g_bsc_tab || ' bsc '
		   || ' WHERE bb.system_id = bsc.system_id AND bb.bsc_id = bsc.bsc_id AND bb.omcr_number = bsc.omcr_number '
		   || ' AND bb.system_id = :system_id AND bsc.msc_id = :msc_id AND bb.bsc_id = :bsc_id '
		   || ' AND bb.system_id = c85.system_id AND bb.bsc_id = c85.bsc_id AND bb.omcr_number = c85.omcr_number '
		   || ' AND bb.bandclass1 = c85.bandclass'
		   || '	) S ON ( '
		   || ' D.system_id = S.system_id AND D.msc_id = S.msc_id AND D.bsc_id = S.bsc_id AND D.bts_id = S.bts_id AND D.carrier_index = S.carrier_index'
		   || ' ) WHEN MATCHED THEN UPDATE SET D.low_sector_bandclass = S.low_sector_bandclass '
		   || ' WHEN NOT MATCHED THEN INSERT (D.system_id, D.msc_id, D.bsc_id, D.bts_id, D.carrier_index, D.low_sector_bandclass) '
		   || ' VALUES (S.system_id, S.msc_id, S.bsc_id, S.bts_id, S.carrier_index, S.low_sector_bandclass)';
		   
		   EXECUTE IMMEDIATE v_sql USING P_SYSTEM_ID, P_MSC_ID, P_BSC_ID;
		   		   
  -- Second, insert low sector bandclass if bandclass1/bandclass2 = 1/14 or 14/1 and no match in first
  -- Do NOT do an update in this stage, or it will overwrite the values from the previous block
  
  v_sql := 'MERGE INTO ' || g_bts_band_tmp || ' D USING ('
  		   || ' SELECT bb.system_id, bsc.msc_id, bb.bsc_id, bb.bts_id, c85.carrier_index, bb.bandclass2 AS low_sector_bandclass '
		   || ' FROM ' || g_bts_band_tab || ' bb, ' || P_CARR_MAP_TAB || ' c85, ' || g_bsc_tab || ' bsc '
		   || ' WHERE bb.system_id = bsc.system_id AND bb.bsc_id = bsc.bsc_id AND bb.omcr_number = bsc.omcr_number '
		   || ' AND bb.system_id = :system_id AND bsc.msc_id = :msc_id AND bb.bsc_id = :bsc_id '
		   || ' AND bb.system_id = c85.system_id AND bb.bsc_id = c85.bsc_id AND bb.omcr_number = c85.omcr_number '
		   || ' AND bb.bandclass2 = c85.bandclass AND ((bb.bandclass1 = 1 AND bb.bandclass2 = 14) OR (bb.bandclass1 = 14 AND bb.bandclass2 = 1))'
		   || '	) S ON ( '
		   || ' D.system_id = S.system_id AND D.msc_id = S.msc_id AND D.bsc_id = S.bsc_id AND D.bts_id = S.bts_id AND D.carrier_index = S.carrier_index'
		   || ' ) WHEN NOT MATCHED THEN INSERT (D.system_id, D.msc_id, D.bsc_id, D.bts_id, D.carrier_index, D.low_sector_bandclass) '
		   || ' VALUES (S.system_id, S.msc_id, S.bsc_id, S.bts_id, S.carrier_index, S.low_sector_bandclass)';
		   
		   EXECUTE IMMEDIATE v_sql USING P_SYSTEM_ID, P_MSC_ID, P_BSC_ID;		   
		   
  -- Third, insert/update high sector bandclass
  -- Generally it will do an update since this column will be null after the execution of the 2 previous blocks
  -- It will also do an insert in the event no records is found after the execution of the 2 blocks above
  
  v_sql := 'MERGE INTO ' || g_bts_band_tmp || ' D USING ('
  		   || ' SELECT bb.system_id, bsc.msc_id, bb.bsc_id, bb.bts_id, c85.carrier_index, bb.bandclass2 AS high_sector_bandclass '
		   || ' FROM ' || g_bts_band_tab || ' bb, ' || P_CARR_MAP_TAB || ' c85, ' || g_bsc_tab || ' bsc '
		   || ' WHERE bb.system_id = bsc.system_id AND bb.bsc_id = bsc.bsc_id AND bb.omcr_number = bsc.omcr_number '
		   || ' AND bb.system_id = :system_id AND bsc.msc_id = :msc_id AND bb.bsc_id = :bsc_id '
		   || ' AND bb.system_id = c85.system_id AND bb.bsc_id = c85.bsc_id AND bb.omcr_number = c85.omcr_number '
		   || ' AND bb.bandclass2 = c85.bandclass '
		   || '	) S ON ( '
		   || ' D.system_id = S.system_id AND D.msc_id = S.msc_id AND D.bsc_id = S.bsc_id AND D.bts_id = S.bts_id AND D.carrier_index = S.carrier_index'
		   || ' ) WHEN MATCHED THEN UPDATE SET D.high_sector_bandclass = S.high_sector_bandclass '
		   || ' WHEN NOT MATCHED THEN INSERT (D.system_id, D.msc_id, D.bsc_id, D.bts_id, D.carrier_index, D.high_sector_bandclass) '
		   || ' VALUES (S.system_id, S.msc_id, S.bsc_id, S.bts_id, S.carrier_index, S.high_sector_bandclass)';
		   
		   EXECUTE IMMEDIATE v_sql USING P_SYSTEM_ID, P_MSC_ID, P_BSC_ID;		   

END;
-- -------------------------------------------------------------------------
-- Trans_To_Tab - translate a temporary table name to the corresponding 
-- traffic table name
-- -------------------------------------------------------------------------
FUNCTION Trans_To_Tab(p_table_name VARCHAR2) RETURN VARCHAR2 IS
BEGIN
      RETURN substr(p_table_name, 1, length(p_table_name)-4)||'_TAB';
END Trans_To_Tab;

-----------------------------------------------------------------------
----------------------- GET_LONG_WML_TABLE  --------------------------
-----------------------------------------------------------------------
FUNCTION Get_Long_WML_Table (p_traffic_tab IN VARCHAR2) RETURN VARCHAR2
AS
	v_sql VARCHAR2(500);
	v_entity_id INTEGER;
	v_wml_tab VARCHAR2(30);
	v_traffic_tab VARCHAR2(30);
BEGIN
	-- Next line is needed in case we passed in a temporary traffic table name
	v_traffic_tab := Trans_To_Tab(p_traffic_tab);
	v_sql := 'SELECT ENTITY_ID FROM WMD_DICT_TABLE WHERE TABLE_NAME = :v_traffic_tab';
	EXECUTE IMMEDIATE v_sql INTO v_entity_id USING v_traffic_tab;
	
	v_wml_tab := 'WML_E' || v_entity_id || '_MAP';
	
	RETURN (v_wml_tab);	
END Get_Long_WML_Table;

-----------------------------------------------------------------------
---------------------------  GET_RANGE  -------------------------------
-----------------------------------------------------------------------

PROCEDURE Get_Range(TABLE_NAME IN VARCHAR2,FULLKEY_COLS IN VARCHAR2, p_system_id IN INTEGER, p_msc_id IN INTEGER, p_bsc_id IN INTEGER,
p_mindate OUT VARCHAR2, p_maxdate OUT VARCHAR2, p_minkey OUT VARCHAR2, p_maxkey OUT VARCHAR2, p_omcr_id OUT VARCHAR2, p_input_row_count OUT INTEGER)
AS
  v_sql VARCHAR2(4000); 
BEGIN
  
  v_sql := 'SELECT TO_CHAR(MIN(TO_DATE(RECORD_DATE || '' '' ||  START_INTERVAL, ''MM/DD/YYYY HH24:MI'')),''MM/DD/YYYY HH24:MI''),'
           || ' TO_CHAR(MAX(TO_DATE(RECORD_DATE  || '' '' ||  START_INTERVAL, ''MM/DD/YYYY HH24:MI'')), ''MM/DD/YYYY HH24:MI''),'
           || ' MIN(' || FULLKEY_COLS || '),'
           || ' MAX(' || FULLKEY_COLS || '),'
           || ' MAX(tmp.omc_id),'
           || ' COUNT(*)'
		   || ' FROM ' || TABLE_NAME || ' tmp'; 		   
	 
    EXECUTE IMMEDIATE v_sql INTO p_mindate, p_maxdate, p_minkey, p_maxkey, p_omcr_id, p_input_row_count
			USING p_system_id, p_msc_id, p_bsc_id, 
				  p_system_id, p_msc_id, p_bsc_id;				  	 
	 
END Get_Range;

-----------------------------------------------------------------------
-------------------------  GET_BIN_RANGE  -----------------------------
-----------------------------------------------------------------------

PROCEDURE Get_Bin_Range(TABLE_NAME IN VARCHAR2,FULLKEY_COLS IN VARCHAR2, p_system_id IN INTEGER, p_msc_id IN INTEGER, p_bsc_id IN INTEGER,
p_mindate OUT VARCHAR2, p_maxdate OUT VARCHAR2, p_minkey OUT VARCHAR2, p_maxkey OUT VARCHAR2, p_omcr_id OUT VARCHAR2, p_input_row_count OUT INTEGER)
AS
  v_sql VARCHAR2(4000);
BEGIN

  v_sql := 'SELECT TO_CHAR(MIN(TO_DATE(RECORD_DATE || '' '' ||  START_INTERVAL, ''MM/DD/YYYY HH24:MI'') - 600/86400 ),''MM/DD/YYYY HH24:MI''),'
           || ' TO_CHAR(MAX(TO_DATE(RECORD_DATE  || '' '' ||  START_INTERVAL, ''MM/DD/YYYY HH24:MI'') + 600/86400),''MM/DD/YYYY HH24:MI''),'
           || ' MIN(' || FULLKEY_COLS || '),'
           || ' MAX(' || FULLKEY_COLS || '),'
           || ' MAX(tmp.omc_id),'
           || ' COUNT(*)'
		   || ' FROM ' || TABLE_NAME || ' tmp';

    EXECUTE IMMEDIATE v_sql INTO p_mindate, p_maxdate, p_minkey, p_maxkey, p_omcr_id, p_input_row_count
			USING p_system_id, p_msc_id, p_bsc_id,
				  p_system_id, p_msc_id, p_bsc_id;

END Get_Bin_Range;

-----------------------------------------------------------------------
-------------------------  GET_RANGE_QRY  -----------------------------
-----------------------------------------------------------------------

PROCEDURE Get_Range_Qry(TABLE_NAME IN VARCHAR2,QRY_TAB_NAME IN VARCHAR2, NUM_OF_SUBJ_IDS IN INTEGER, FULLKEY_COLS IN VARCHAR2, 
p_system_id IN INTEGER, p_msc_id IN INTEGER, p_bsc_id IN INTEGER,
p_mindate OUT VARCHAR2, p_maxdate OUT VARCHAR2, p_minkey OUT VARCHAR2, p_maxkey OUT VARCHAR2, p_omcr_id OUT VARCHAR2, p_input_row_count OUT INTEGER)
AS
  v_sql VARCHAR2(4000);
  subj_id_count INTEGER := 1; 
BEGIN  
-- Next if block is specific to valnt00013005 and relates to PMC81_PC3_4 in MOT_TF_C_PM_CELL_SECTOR_TAB
  -- It is used in MOT_JLOADER_OMCR_PM.load_cell_sector_int
  
  IF QRY_TAB_NAME = 'MOT_TF_C_PM_CELL_SECTOR_LTM' THEN
          
      v_sql := 'SELECT /*+ CARDINALITY(tmp 1000) */ '
                   || 'TO_CHAR(MIN(TO_DATE(tmp.RECORD_DATE || '' '' ||  tmp.START_INTERVAL, ''MM/DD/YYYY HH24:MI'')),''MM/DD/YYYY HH24:MI''),'
           || ' TO_CHAR(MAX(TO_DATE(tmp.RECORD_DATE  || '' '' ||  tmp.START_INTERVAL, ''MM/DD/YYYY HH24:MI'')), ''MM/DD/YYYY HH24:MI''),'
           || ' MIN(' || FULLKEY_COLS || '),'
           || ' MAX(' || FULLKEY_COLS || '),'
           || ' MAX(tmp.omc_id),'
           || ' COUNT(*)'
                   || ' FROM ' || TABLE_NAME || ' tmp, ' || QRY_TAB_NAME || ' ltm'
                   || ' WHERE :p_system_id = SUBSTR ( ltm.id , 1, INSTR( ltm.id,''-'',1,1)-1 ) '
                   || ' AND :p_msc_id = SUBSTR ( ltm.id ,INSTR( ltm.id,''-'',1,1)+1, INSTR( ltm.id,''-'',1,2)-INSTR( ltm.id,''-'',1,1)-1 )'
                   || ' AND tmp.mm_id = SUBSTR ( ltm.id ,INSTR( ltm.id,''-'',1,2)+1, INSTR( ltm.id,''-'',1,3)-INSTR( ltm.id,''-'',1,2)-1 ) '
                   || ' AND tmp.subj_id_1 = SUBSTR ( ltm.id ,INSTR( ltm.id,''-'',1,3)+1, INSTR( ltm.id,''-'',1,4)-INSTR( ltm.id,''-'',1,3)-1 )'
;

        EXECUTE IMMEDIATE v_sql INTO p_mindate, p_maxdate, p_minkey, p_maxkey, p_omcr_id, p_input_row_count
                        USING p_system_id, p_msc_id, p_bsc_id,
                                  p_system_id, p_msc_id, p_bsc_id,
                                  p_system_id, p_msc_id;
  ELSE
	  v_sql := 'SELECT /*+ CARDINALITY(tmp 1000) */ '
  		   || 'TO_CHAR(MIN(TO_DATE(tmp.RECORD_DATE || '' '' ||  tmp.START_INTERVAL, ''MM/DD/YYYY HH24:MI'')),''MM/DD/YYYY HH24:MI''),'
           || ' TO_CHAR(MAX(TO_DATE(tmp.RECORD_DATE  || '' '' ||  tmp.START_INTERVAL, ''MM/DD/YYYY HH24:MI'')), ''MM/DD/YYYY HH24:MI''),'
           || ' MIN(' || FULLKEY_COLS || '),'
           || ' MAX(' || FULLKEY_COLS || '),'
           || ' MAX(tmp.omc_id),'
           || ' COUNT(*)'
		   || ' FROM ' || TABLE_NAME || ' tmp, ' || QRY_TAB_NAME || ' qry'
		   || ' WHERE tmp.omc_id = qry.omc_id AND tmp.mm_id = qry.mm_id ';

	 IF NUM_OF_SUBJ_IDS > 0 THEN
	 	FOR subj_id_count IN 1..NUM_OF_SUBJ_IDS LOOP	 	   
		   v_sql := v_sql || ' AND tmp.subj_id_' || subj_id_count || ' = qry.subj_id_' || subj_id_count;
	 	END LOOP;
	 END IF;		   	    	   	 		   		   	 	 
	 
    EXECUTE IMMEDIATE v_sql INTO p_mindate, p_maxdate, p_minkey, p_maxkey, p_omcr_id, p_input_row_count
			USING p_system_id, p_msc_id, p_bsc_id,
				  p_system_id, p_msc_id, p_bsc_id;
  END IF;					
END Get_Range_Qry;						

-----------------------------------------------------------------------
-------------------------  GET_RANGE_CARR  ----------------------------
-----------------------------------------------------------------------

PROCEDURE Get_Range_Carr(TABLE_NAME IN VARCHAR2,CARR_MAP_TAB IN VARCHAR2, FULLKEY_COLS IN VARCHAR2, p_system_id IN INTEGER, p_msc_id IN INTEGER, p_bsc_id IN INTEGER,
p_mindate OUT VARCHAR2, p_maxdate OUT VARCHAR2, p_minkey OUT VARCHAR2, p_maxkey OUT VARCHAR2, p_omcr_id OUT VARCHAR2, p_input_row_count OUT INTEGER)
AS
  v_sql VARCHAR2(4000);
  v_pmc	INTEGER; 
  v_bsc_map_tab VARCHAR2(30) := 'MOT_PM_MAP_BSC_TAB';
  v_bts_band_tab VARCHAR2(30) := 'MOT_PM_MAP_BTS_BAND_TAB';
 v_bts_band_tmp VARCHAR2(30) := 'MOT_PM_MAP_BTS_BAND_TMP';
  v_sector_col VARCHAR2(30) := 'tmp.subj_id_2';
  v_nbb_count INTEGER := 0;
BEGIN

  v_pmc := TO_NUMBER(SUBSTR(TABLE_NAME,INSTR(TABLE_NAME,'_',1)+1,INSTR(TABLE_NAME,'_',-1)-INSTR(TABLE_NAME,'_',1)-1));

  v_sql := 'SELECT TO_CHAR(MIN(TO_DATE(RECORD_DATE || '' '' || START_INTERVAL, ''MM/DD/YYYY HH24:MI'')),''MM/DD/YYYY HH24:MI''),'
           || ' TO_CHAR(MAX(TO_DATE(RECORD_DATE || '' '' || START_INTERVAL, ''MM/DD/YYYY HH24:MI'')),''MM/DD/YYYY HH24:MI''),'
           || ' MIN(' || FULLKEY_COLS || '),'
           || ' MAX(' || FULLKEY_COLS || '),'
           || ' MAX(tmp.omc_id),'
           || ' COUNT(*)';
		   
		   IF CARR_MAP_TAB = 'MOT_PM_MAP_CARR_TAB' THEN
		   
		   	  v_sql := v_sql || ' FROM ' || TABLE_NAME || ' tmp,' || CARR_MAP_TAB || ' map, ' || v_bsc_map_tab || ' bsc'
			       	   		 || ' WHERE map.system_id  = :p_system_id'
     	   					 || ' AND bsc.msc_id     = :p_msc_id'
     	   					 || ' AND map.bsc_id     = :p_bsc_id'
							 || ' AND bsc.system_id = map.system_id'
							 || ' AND bsc.bsc_id = map.bsc_id'
							 || ' AND bsc.omcr_number = map.omcr_number';
							 
		   
		   ELSIF CARR_MAP_TAB = 'MOT_PM_85_MAP_CARR_TAB' THEN
                         
			 update_bts_band_tmp(p_system_id, p_msc_id, p_bsc_id, CARR_MAP_TAB);

		   

                        v_sql :=  v_sql || '    FROM ' || TABLE_NAME || ' tmp, ' || v_bsc_map_tab || ' bsc, ' || CARR_MAP_TAB || ' map, ' || v_bts_band_tmp || ' nbb '
     	                                         || ' WHERE map.system_id  = :p_system_id'
     	   					 || ' AND bsc.msc_id     = :p_msc_id'
                                                 || '    AND bsc.bsc_id = :p_bsc_id'
                                                         || '    AND tmp.omc_id = bsc.omcr_number'
                                                         || '    AND tmp.mm_id = bsc.bsc_id'
                                                         || '    AND bsc.system_id = nbb.system_id'
                                                         || '    AND tmp.omc_id = bsc.omcr_number'
                                                         || '    AND tmp.mm_id = nbb.bsc_id'
                                                         || '    AND tmp.subj_id_1 = nbb.bts_id'
                                                         || '    AND bsc.system_id = map.system_id'
                                                         || '    AND tmp.omc_id = map.omcr_number'
                                                         || '    AND tmp.mm_id = map.bsc_id'
                                                         || '     AND nbb.carrier_index = map.carrier_index'
                                                         || '     AND map.bandclass = '
                                                         || '     CASE WHEN (' || v_sector_col || ' > 6) THEN nbb.high_sector_bandclass '
                                                         || '     WHEN(' || v_sector_col || ' >= 1 AND ' || v_sector_col || ' <= 6) THEN '
                                                         || '     nbb.low_sector_bandclass '
                                                         || '     ELSE NULL END ';

		   END IF;
		   
		   
		   IF v_pmc = 20 OR v_pmc = 25 OR v_pmc = 26 OR v_pmc = 27 OR v_pmc = 29 OR v_pmc = 40 OR v_pmc = 41 OR v_pmc = 42 
		   	  OR v_pmc = 43 OR v_pmc = 44 OR v_pmc = 46 OR v_pmc = 47 OR v_pmc = 48 OR v_pmc = 117
		   THEN			  
		   	  v_sql := v_sql || ' 	 AND tmp.subj_id_4 = map.carrier_index';
		   ELSE	  
		   	  v_sql := v_sql || ' 	 AND tmp.subj_id_3 = map.carrier_index';
		   END IF;		   	   
	 
    EXECUTE IMMEDIATE v_sql INTO p_mindate, p_maxdate, p_minkey, p_maxkey, p_omcr_id, p_input_row_count
			USING p_system_id, p_msc_id, p_bsc_id, 
				  p_system_id, p_msc_id, p_bsc_id,
				  p_system_id, p_msc_id, p_bsc_id;				  	 
	 
END Get_Range_Carr;	 

-----------------------------------------------------------------------
-------------------------  GET_RANGE_BSC  ----------------------------
-----------------------------------------------------------------------

PROCEDURE Get_Range_BSC(TABLE_NAME IN VARCHAR2,BSC_MAP_TAB IN VARCHAR2, FULLKEY_COLS IN VARCHAR2, p_system_id IN INTEGER, 
p_mindate OUT VARCHAR2, p_maxdate OUT VARCHAR2, p_minkey OUT VARCHAR2, p_maxkey OUT VARCHAR2, p_omcr_id OUT VARCHAR2, p_input_row_count OUT INTEGER)
AS
  v_sql VARCHAR2(4000);
  v_pmc	INTEGER;
BEGIN

  v_sql := 'SELECT TO_CHAR(MIN(TO_DATE(RECORD_DATE || '' '' || START_INTERVAL, ''MM/DD/YYYY HH24:MI'')),''MM/DD/YYYY HH24:MI''),'
           || ' TO_CHAR(MAX(TO_DATE(RECORD_DATE || '' '' || START_INTERVAL, ''MM/DD/YYYY HH24:MI'')),''MM/DD/YYYY HH24:MI''),'
           || ' MIN(' || FULLKEY_COLS || '),'
           || ' MAX(' || FULLKEY_COLS || '),'
           || ' MAX(tmp.omc_id),'
           || ' COUNT(*)'
           || ' FROM ' || TABLE_NAME || ' tmp,' || BSC_MAP_TAB || ' map'
     	   || ' WHERE map.system_id  = :p_system_id'
     	   || ' AND map.bsc_id       = tmp.mm_id'
     	   || ' AND map.omcr_number  = tmp.omc_id';		   

    EXECUTE IMMEDIATE v_sql INTO p_mindate, p_maxdate, p_minkey, p_maxkey, p_omcr_id, p_input_row_count
			USING p_system_id, p_system_id, p_system_id ;

END Get_Range_BSC;

-----------------------------------------------------------------------
-------------------------  GET_RANGE_OMCR  ----------------------------
-----------------------------------------------------------------------

PROCEDURE Get_Range_OMCR(TABLE_NAME IN VARCHAR2,FULLKEY_COLS IN VARCHAR2, p_system_id IN INTEGER,
p_mindate OUT VARCHAR2, p_maxdate OUT VARCHAR2, p_minkey OUT VARCHAR2, p_maxkey OUT VARCHAR2, p_omcr_id OUT VARCHAR2, p_input_row_count OUT INTEGER)
AS
  v_sql VARCHAR2(4000); 
BEGIN
  
  v_sql := 'SELECT TO_CHAR(MIN(TO_DATE(RECORD_DATE || '' '' ||  START_INTERVAL, ''MM/DD/YYYY HH24:MI'')),''MM/DD/YYYY HH24:MI''),'
           || ' TO_CHAR(MAX(TO_DATE(RECORD_DATE  || '' '' ||  START_INTERVAL, ''MM/DD/YYYY HH24:MI'')), ''MM/DD/YYYY HH24:MI''),'
           || ' MIN(' || FULLKEY_COLS || '),'
           || ' MAX(' || FULLKEY_COLS || '),'
           || ' MAX(tmp.omc_id),'
           || ' COUNT(*)'
	   || ' FROM ' || TABLE_NAME || ' tmp'; 		   
	 
    EXECUTE IMMEDIATE v_sql INTO p_mindate, p_maxdate, p_minkey, p_maxkey, p_omcr_id, p_input_row_count
			USING p_system_id, p_system_id;
	 
END Get_Range_OMCR;

-----------------------------------------------------------------------
------------------------  CREATE_TEMP_TABLE  --------------------------
-----------------------------------------------------------------------

PROCEDURE CREATE_TEMP_TABLE (DATA_TYPE IN VARCHAR2, RECORD_TYPE IN VARCHAR2, NUM_OF_SUBJ_IDS IN INTEGER)
AS
  v_record_type VARCHAR2(5);
  v_pcount INTEGER := 1;
  v_create_tmp_sql VARCHAR2(4000); 
BEGIN
	 IF TO_NUMBER(RECORD_TYPE) < 10 THEN
	 	v_record_type := '0' || RECORD_TYPE;
	 ELSE
	    v_record_type := RECORD_TYPE;
	 END IF;  
	 
  	 v_create_tmp_sql := 'CREATE GLOBAL TEMPORARY TABLE ' || DATA_TYPE || '_' || v_record_type || '_TMP ('
  				   				  	 || ' RECORD_DATE     VARCHAR2(20),'
  									 || ' START_INTERVAL  VARCHAR2(20),'
  									 || ' END_INTERVAL    VARCHAR2(20),'
  									 || ' OMC_ID    	  NUMBER(10),'
  									 || ' MM_ID			  NUMBER(10)';  	 

	 -- Next block to handle subj_id counters and defaults to NUMBER(10)
	 IF NUM_OF_SUBJ_IDS > 0 THEN	 
	 	FOR subj_id_count IN 1..NUM_OF_SUBJ_IDS LOOP
	 		v_create_tmp_sql := v_create_tmp_sql || ',SUBJ_ID_' || subj_id_count || ' NUMBER(10)';
	 	END LOOP;
	 END IF;
		 		 
	 -- Get a list of columns that conforms to the format PMCx_PCy, where x is the record_type and y is the peg count number
	 FOR RECTYPE_CUR IN (SELECT DISTINCT(COLUMN_NAME), DATA_TYPE, DATA_LENGTH, DATA_PRECISION, DATA_SCALE,
	 	 TO_NUMBER(SUBSTR(COLUMN_NAME,INSTR(COLUMN_NAME,'PC')+2)) AS PC FROM COLS 
	 	 WHERE COLUMN_NAME LIKE 'PMC' || v_record_type || '\_PC%' ESCAPE '\'
		 AND ((INSTR(COLUMN_NAME,'_',-1)='6') OR (INSTR(COLUMN_NAME,'_',-1)='7')) AND TABLE_NAME LIKE '%\_TAB' ESCAPE '\' ORDER BY PC ASC)
	 LOOP
	 
	 	 --DBMS_OUTPUT.PUT_LINE('PC: ' || RECTYPE_CUR.PC || ' AND v_pcount: ' || v_pcount);
		 -- Next block to handle counters that are not supported in traffic tables but required in the temp tables for loading	 	 
		 -- Defaults to FLOAT(126) in case we need to use it in the future
		 WHILE RECTYPE_CUR.PC <> v_pcount LOOP
	 	 	   v_create_tmp_sql := v_create_tmp_sql || ', PMC' || v_record_type || '_PC' || v_pcount || ' NUMBER(10)';
			   v_pcount := v_pcount + 1;
		 END LOOP;		

				 		 
	 	 	IF RECTYPE_CUR.DATA_TYPE = 'NUMBER' THEN
			   IF RECTYPE_CUR.DATA_PRECISION > 0 AND RECTYPE_CUR.DATA_SCALE > 0 THEN
	 	 	   	  v_create_tmp_sql := v_create_tmp_sql || ',' || RECTYPE_CUR.COLUMN_NAME || ' NUMBER(' || RECTYPE_CUR.DATA_PRECISION || ',' || RECTYPE_CUR.DATA_SCALE || ')';
			   ELSIF RECTYPE_CUR.DATA_PRECISION > 0 THEN
	 	 	   	  v_create_tmp_sql := v_create_tmp_sql || ',' || RECTYPE_CUR.COLUMN_NAME || ' NUMBER(' || RECTYPE_CUR.DATA_PRECISION || ')';
			   ELSE
	 	 	   	  v_create_tmp_sql := v_create_tmp_sql || ',' || RECTYPE_CUR.COLUMN_NAME || ' NUMBER';
			   END IF;			   				  
	 	 	ELSIF RECTYPE_CUR.DATA_TYPE = 'FLOAT' THEN		 		 
	 	 	v_create_tmp_sql := v_create_tmp_sql || ',' || RECTYPE_CUR.COLUMN_NAME || ' FLOAT(' || RECTYPE_CUR.DATA_PRECISION || ')';		 
	 	 	ELSIF RECTYPE_CUR.DATA_TYPE = 'VARCHAR2' OR RECTYPE_CUR.DATA_TYPE = 'VARCHAR' THEN		 		 
	 	 	v_create_tmp_sql := v_create_tmp_sql || ',' || RECTYPE_CUR.COLUMN_NAME || ' VARCHAR2(' || RECTYPE_CUR.DATA_LENGTH || ')';
		 	ELSIF RECTYPE_CUR.DATA_TYPE = 'DATE' THEN
	 	 	v_create_tmp_sql := v_create_tmp_sql || ',' || RECTYPE_CUR.COLUMN_NAME || ' DATE';		 
		    END IF;
	 	    v_pcount := v_pcount + 1;			
		 		 		 
	 END LOOP;
 	 v_create_tmp_sql := v_create_tmp_sql || ' ) ON COMMIT PRESERVE ROWS';
	 
	 EXECUTE IMMEDIATE v_create_tmp_sql; 		 	 	 	 	 	 
	 
END CREATE_TEMP_TABLE;

-----------------------------------------------------------------------
-------------------  WRITE_POSTLOAD_MERGE_STRINGS  --------------------
-----------------------------------------------------------------------

PROCEDURE WRITE_POSTLOAD_MERGE_STRINGS(p_record_type IN VARCHAR2, p_table_name IN VARCHAR2,
				 p_select_param_list OUT VARCHAR2,
				 p_update_list OUT VARCHAR2,
				 p_insert_param_list OUT VARCHAR2,
				 p_insert_value_list OUT VARCHAR2) IS
      i BINARY_INTEGER;
      TYPE lt_table_arr IS TABLE OF VARCHAR2(30);
      la_table_arr lt_table_arr;
      lv_col       VARCHAR2(30);
      slv_col       VARCHAR2(30);	  	
 
   BEGIN

   	  p_update_list := 'D.instance_id=S.instance_id';
      p_insert_param_list := 'D.id, D.tstamp, D.instance_id';
      p_insert_value_list := 'S.loaderkey, S.tstamp, S.instance_id';

      SELECT utc.column_name BULK COLLECT INTO la_table_arr
	  FROM USER_TAB_COLUMNS utc
	  WHERE utc.table_name = p_table_name
	  AND utc.column_name NOT IN ('ID', 'TSTAMP', 'FULLKEY', 'INSTANCE_ID')
	  AND utc.column_name LIKE 'PMC' || p_record_type || '\_%' ESCAPE '\';

	  IF SQL%ROWCOUNT > 0 THEN
      	 FOR i IN la_table_arr.first..la_table_arr.last 
		 LOOP
	 	 	 lv_col := la_table_arr(i);
	 		 IF SUBSTR(lv_col,INSTR(lv_col,'_')+1, 7) = 'SUBJ_ID' THEN
				slv_col := SUBSTR(lv_col,INSTR(lv_col,'_')+1, LENGTH(lv_col));
	 		 ELSE
	 	 	 	 slv_col := lv_col;
	 		 END IF;		 
 
	 	p_update_list := p_update_list || ',D.' || lv_col || '=S.' || slv_col;
	 	p_select_param_list := p_select_param_list||',tmp.'||slv_col;	 
	 	p_insert_param_list := p_insert_param_list||',D.'||lv_col;
	 	p_insert_value_list := p_insert_value_list||',S.'||slv_col;
	 
      	END LOOP;
	  
	  -- Remove the initial comma
	  p_select_param_list := SUBSTR(p_select_param_list,2, LENGTH(p_select_param_list)-1);
	    
	ELSE
		DBMS_OUTPUT.PUT_LINE('No rows returned!');
	END IF;
	
END WRITE_POSTLOAD_MERGE_STRINGS;

FUNCTION Get_CarrMapTab (p_system_id IN INTEGER, p_bsc_id IN INTEGER, p_omcr_num IN INTEGER) 
RETURN VARCHAR2
IS
    v_sql VARCHAR2(500);
	v_carr_map_tab VARCHAR2(30);
	v_mmtype_tab VARCHAR2(30) := 'MOT_PM_MAP_MMTYPE_TAB';
BEGIN
   	v_sql := 'SELECT DECODE(mmtype,0,''MOT_PM_MAP_CARR_TAB'',1, ''MOT_PM_85_MAP_CARR_TAB'', NULL)'
		  	 || ' FROM ' || v_mmtype_tab 
		  	 || ' WHERE system_id=' || p_system_id || ' AND bsc_id=' || p_bsc_id
			 || ' AND omcr_number=' || p_omcr_num;

--	dbms_output.put_line(v_sql);		 
	
	EXECUTE IMMEDIATE v_sql INTO v_carr_map_tab;			 
			 
	RETURN v_carr_map_tab;
	
	EXCEPTION 
	WHEN NO_DATA_FOUND THEN	
		 RETURN NULL;
	
END Get_CarrMapTab;

END MOT_JLOADER_COMMON;
/
show errors;
