#!/bin/ksh
########################################################
# @(#) install.sh 08/10/13 13:23:33
# @(#) 
# Copyright 2008 IBM Corp.
########################################################

########################################################
# 
# MotoCDMA Direct RP4.1 -> MotoCDMA Direct RP4.2 Server Upgrade script
# 
########################################################

  RELEASE="MotoEVDO"
  VERSION="8.0.4.2.0"
  BUILD="2"
  PRODUCT_RELEASE="22.0.4.2.0"
  FULL_VER="${VERSION}.${BUILD}"

########################################################

  SOURCE_DIR="$FLEXPM_BASE/patches/$PRODUCT_RELEASE.${BUILD}/$RELEASE/$FULL_VER"
  BACKUP_DIR="$FLEXPM_BASE/patches/$PRODUCT_RELEASE.${BUILD}/$RELEASE/$FULL_VER/backup.${FULL_VER}"

########################################################

  function patchsql 
  {
    echo Patching: $1
    echo "WHENEVER SQLERROR CONTINUE;\nSET SERVEROUTPUT ON SIZE 1000000;\nSET TIMING ON;\n@ $1 \nEXIT;" | sqlplus -S $DB_CONNECT
    status=$?
    test "${status}" = "0" || exit ${status}
  }

########################################################

 echo "$RELEASE RP4.1 -> RP4.2 Server Upgrade"
 echo "Start: " `date`
    
########################################################
echo "Checking environment..."
########################################################

  if ! [[ -d ${FLEXPM_HOME} ]]; then
    echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    exit;
  fi

  if ! [[ -d ${FLEXPM_BASE} ]]; then
    echo "Env variable FLEXPM_BASE must be set to appropriate dir before installation."
    exit;
  fi

  if ! [[ -d ${PM_HOME} ]]; then
    echo "Env variable FLEXPM_BASE must be set to appropriate dir before installation."
    exit;
  fi
  
  if ! [[ -d ${MotoEVDO_HOME} ]]; then
    echo "Env variable MotoEVDO_HOME must be set to appropriate dir before installation."
    exit;
  fi

  if [[ -z ${DB_CONNECT} ]]; then
     echo "Env variable DB_CONNECT must be set to approriate database connection values."
     exit;
  fi
  
  if [[ -d ${BACKUP_DIR} ]]; then
           echo "Patch ${RELEASE} may have been already applied. Please verify.\n"
           exit
  else
           mkdir -p -m 744 ${BACKUP_DIR}
  fi

       ####################### pre-requisite validation ###########################
       ############################################################################

       pre_err="N"

       ### chk for PERL5LIB
       echo $PERL5LIB | grep "$PM_HOME/sw/perl/lib"
       ret=$?

       if [ $ret == 1 ] ; then
	  export PERL5LIB=$PM_HOME/sw/perl/lib
       fi

       ### chk for perl version
       perl -v | fgrep 5.6.1 >/dev/null 2>&1
       ret=$?

       if [ "$force" == "N" ] &&  [ $ret == 1 ] ; then
          echo
          echo "Invalid perl version.  Prospect must be using perl version 5.6.1!"
          pre_err="Y" 
       fi

       ### chk for java version
       ret=`java -version 2>&1 | sed -n -e '/java version/{ s/^.* "//; s/".*$//; s/_.*//; p;}' | awk -F. '{ printf("%02d.%02d.%02d\n",$1,$2,$3)}' `

       if [ "$force" == "N" ] && [[ $ret < 01.04.02 ]] ; then
          echo
          echo "Invalid Java version.  Java version must be same as or above 01.04.02!"
          pre_err="Y"
       fi 

       ### chk for conflict variable

       if [ "$force" == "N" ] && ! [ -z ${LOG} ] ; then
          echo
          echo "Variable \$LOG is defined.  This might impact on Prospect System.  Please unset this varable manually by typing 'unset LOG'"
          pre_err="Y"
       fi

        if [ "$force" == "N" ] && ! [ -z ${OK} ] ; then
          echo
          echo "Variable \$OK is defined.  This might impact on Prospect System.  Please unset this varable manually by typing 'unset OK'"
          pre_err="Y"
       fi

       if [ "$pre_err" == "Y" ] ; then
          echo
          echo "Error in pre-requisite validation.  Please contact IBM Customer Support before proceeding installation."
          exit 3
       fi

      #################### End of pre-requisite validation #######################
      ############################################################################
  
########################################################
echo "Installing updated source files..."
########################################################

  cd $SOURCE_DIR/sources
  for new_dir in `find . -type d|cut -c3-`
  do
        if [[ -d ${FLEXPM_BASE}/$new_dir ]]; then
          echo "dir ok: $new_dir"
        else
          echo "create: $new_dir"
          mkdir -p ${FLEXPM_BASE}/$new_dir
        fi

  done

  touch ${BACKUP_DIR}/backup_sources.tar

  cd $SOURCE_DIR/sources

  for new_file in `find . -type f|cut -c3-`
  do
        cd ${FLEXPM_BASE}
        if [[ -f $new_file ]];
        then
          echo "backup: ${FLEXPM_BASE}/$new_file"
          /usr/sfw/bin/gtar -uf ${BACKUP_DIR}/backup_sources.tar $new_file
          chmod +w $new_file
        fi
        echo "update: ${FLEXPM_BASE}/$new_file"
        cp -p ${SOURCE_DIR}/sources/$new_file $new_file
  
  done

########################################################
echo "Setup bits..."
########################################################

cd $FLEXPM_HOME
chmod +x pm/adm/setup-exec-bits
setup-exec-bits -set

########################################################
######### AE UPGRADE STARTS HERE  
########################################################

echo "+ Starting dict_update for MotoEVDO"
cd $MotoEVDO_HOME/peik
make dict_update

#Make R8 sentry and filedecode
echo "+ Creating directory for MotoEVDO R8..."
cd ${MotoEVDO_HOME}/vendor/Motorola/BSCDO/1.3/scripts
make clean
make all

########################################################
    echo "+ Make loader ..."
########################################################

#Make EVDO_PM loader
#Not use "make clean make all" to avoid ORA-00942 on new tables. Used dropTmp_EVDO_PM.sql instead.
echo "+ Update EVDO_PM datatype..."
cd $MotoEVDO_HOME/vendor/Motorola/BSCDO/1.3/MotoEVDO_loader/EVDO_PM/config
patchsql $SOURCE_DIR/dropTmp_EVDO_PM.sql
rm -fr BUILD DROP LOAD_CONTROL
rm -f LoaderControl.txt DatabaseTable.txt DatabaseFile.txt
rm -f ../data/LoaderControl.txt ../data/DatabaseTable.txt
make all

#Make aemsC_PM loader
echo "+ Update aemsC_PM datatype..."
cd $MotoEVDO_HOME/vendor/Motorola/BSCDO/1.3/MotoEVDO_loader/aemsC_PM
#As a replacement to make tpl_create_exts
sed 's/mot_aemsc_pm_dir/mot_aemsc_pm_'${DBUSER}'_aemsC_DIR/g' create_mot_aemsc_pm_exts.tpl > create_mot_aemsc_pm_exts.sql
make recompile
patchsql $SOURCE_DIR/drop_mot_aemsc_pm_tabs_RP4.2.sql
sed 's/moto3/'${DBUSER}'/g' $SOURCE_DIR/create_mot_aemsc_pm_exts_RP4.2.sql > $FLEXPM_BASE/create_mot_aemsc_pm_exts_RP4.2.sql
patchsql $FLEXPM_BASE/create_mot_aemsc_pm_exts_RP4.2.sql
rm $FLEXPM_BASE/create_mot_aemsc_pm_exts_RP4.2.sql
patchsql $SOURCE_DIR/create_mot_aemsc_pm_tmps_RP4.2.sql
patchsql create_mot_aemsc_pm_load_pkgb.sql

echo "+ Updating MotoEVDO loader configuration files..."
cd $MotoEVDO_HOME/vendor/Motorola/BSCDO/1.3/MotoEVDO_data
make clean
make all

########################################################
echo "Compile EVDO network packages and EVDO Load Limits"
########################################################

cd $MotoEVDO_HOME/vendor/Motorola/BSCDO/Network
patchsql moto_evdo_load_pkg.sql
patchsql moto_evdo_load_pkgb.sql
make postload

cd $MotoEVDO_HOME/post-vendor
make UPDSCRIPT

patchsql $SOURCE_DIR/restore_part_maint.sql
patchsql $SOURCE_DIR/regen_XML.sql
patchsql $SOURCE_DIR/wmload_create.sql

# SEAde69755
chmod 775 `find $PROSPECT_HOME/../ftpIN -type d`
chmod 775 `find $MotoCDMA_HOME/vendor/Motorola/MSC/ftpIN -type d`
chmod 775 `find $MotoEVDO_HOME/vendor/Motorola/BSCDO/ftpIN -type d`

#Replace Helpfiles
cd $SOURCE_DIR
chmod 755 $PM_HOME/vendor/Common/NE/ProductRelease/HelpFiles/*.uue
cp *.uue $PM_HOME/vendor/Common/NE/ProductRelease/HelpFiles

$SOURCE_DIR/recompile_schema.sh
$SOURCE_DIR/recompile_view.sh

patchsql $MotoEVDO_HOME/post-vendor/entityorder.sql

#Introduced so that RP4.1 installation does not throw error.
cd $PROSPECT_HOME/scripts
if [[ -f export_docs.sh ]]
then
   rm export_docs.sh
fi

if [[ -f import_docs.sh ]]
then
   rm import_docs.sh
fi


########################################################
######### AE UPGRADE ENDS HERE  
########################################################
 
cd $SOURCE_DIR
  
  echo "End: " `date`
  
  echo "Installation Complete - Check for errors."
  
########################################################
